database

package
v0.2.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jan 1, 2020 License: AGPL-3.0 Imports: 8 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func ParseDB

func ParseDB(r io.Reader, cb PacketCallback) error

ParseDB reads a pacman .db file and will call cb for each packet

func ParseDBFromFile

func ParseDBFromFile(filename string, cb PacketCallback) error

ParseDBFromFile reads a pacman .db file and call cb for each packet directly from File

func ParseDBFromFileSlice

func ParseDBFromFileSlice(filename string) ([]packet.Packet, error)

ParseDBFromFileSlice reads a pacman .db file and creates a []packet.Packet directly from File

func ParseDBGUnzipped

func ParseDBGUnzipped(r io.Reader, cb PacketCallback) error

ParseDBGUnzipped reads a pacman .db file and will call cb for each packet

func ParseDBGUnzippedSlice

func ParseDBGUnzippedSlice(r io.Reader) ([]packet.Packet, error)

ParseDBGUnzippedSlice reads a pacman .db file and creates a []packet.Packet

func ParseDBSlice

func ParseDBSlice(r io.Reader) ([]packet.Packet, error)

ParseDBSlice reads a pacman .db file and creates a []packet.Packet

Types

type PacketCallback

type PacketCallback func(*packet.Packet, io.Reader)

PacketCallback is a callback for packets that will receive the packet parsed from the filename and a reader containing the rest of the packages "desc" file with further information

type Repository

type Repository struct {
	Name string
	Arch string
}

Repository describes a Repo as found on an upstream server

func (Repository) String

func (r Repository) String() string

Jump to