mirrorlist

package
v0.2.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jan 1, 2020 License: AGPL-3.0 Imports: 8 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Mirror

type Mirror string

Mirror represents the URL of an Arch Linux mirror server

func (Mirror) PacketURL

func (m Mirror) PacketURL(p *packet.Packet, repo *database.Repository) string

PacketURL returns the actual URL of a given packet

func (Mirror) RepoURL

func (m Mirror) RepoURL(repo *database.Repository) string

RepoURL returns the actual URL of a given repo db

type Mirrorlist

type Mirrorlist []Mirror

Mirrorlist represents a list of Arch Linux mirror server URLs

func FromFile

func FromFile(filename string) (Mirrorlist, error)

FromFile reads the given mirrorlist file and returns the content URLs

func FromReader

func FromReader(r io.Reader) (Mirrorlist, error)

FromReader reads a mirrorlist from the given reader and returns the URLs

Jump to