Documentation
¶
Index ¶
- func ParseDB(r io.Reader, cb PacketCallback) error
- func ParseDBFromFile(filename string, cb PacketCallback) error
- func ParseDBFromFileSlice(filename string) ([]packet.Packet, error)
- func ParseDBGUnzipped(r io.Reader, cb PacketCallback) error
- func ParseDBGUnzippedSlice(r io.Reader) ([]packet.Packet, error)
- func ParseDBSlice(r io.Reader) ([]packet.Packet, error)
- type PacketCallback
- type Repository
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func ParseDB ¶
func ParseDB(r io.Reader, cb PacketCallback) error
ParseDB reads a pacman .db file and will call cb for each packet
func ParseDBFromFile ¶
func ParseDBFromFile(filename string, cb PacketCallback) error
ParseDBFromFile reads a pacman .db file and call cb for each packet directly from File
func ParseDBFromFileSlice ¶
ParseDBFromFileSlice reads a pacman .db file and creates a []packet.Packet directly from File
func ParseDBGUnzipped ¶
func ParseDBGUnzipped(r io.Reader, cb PacketCallback) error
ParseDBGUnzipped reads a pacman .db file and will call cb for each packet
func ParseDBGUnzippedSlice ¶
ParseDBGUnzippedSlice reads a pacman .db file and creates a []packet.Packet
Types ¶
type PacketCallback ¶
PacketCallback is a callback for packets that will receive the packet parsed from the filename and a reader containing the rest of the packages "desc" file with further information
type Repository ¶
Repository describes a Repo as found on an upstream server
func (Repository) String ¶
func (r Repository) String() string
Click to show internal directories.
Click to hide internal directories.