Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Mirror ¶
type Mirror string
Mirror represents the URL of an Arch Linux mirror server
type Mirrorlist ¶
type Mirrorlist []Mirror
Mirrorlist represents a list of Arch Linux mirror server URLs
func FromFile ¶
func FromFile(filename string) (Mirrorlist, error)
FromFile reads the given mirrorlist file and returns the content URLs
func FromReader ¶
func FromReader(r io.Reader) (Mirrorlist, error)
FromReader reads a mirrorlist from the given reader and returns the URLs
Click to show internal directories.
Click to hide internal directories.